#ifdef _WINDOWS
#include <windows.h>
#endif

#include "CSimpCamera.h"
#include <gl\glu.h>

CSimpCamera::CSimpCamera(float posx, float posy, float posz, float yaw, float pitch)
{
  m_pos.Set(posx, posy, posz);
  m_up.Set(0.0, 1.0, 0.0);
  m_rotX = 0;
  m_rotY = 0;
  YawAndPitch(yaw, pitch);
}

CSimpCamera::CSimpCamera()
{
  m_pos.Set(0.0, 0.0, 0.0);
  m_up.Set(0.0, 1.0, 0.0);
  m_rotX = 0;
  m_rotY = 0;
  YawAndPitch(0, 0);
}

void CSimpCamera::SetView()
{
  gluLookAt(m_pos.x, m_pos.y, m_pos.z,
            m_lookat.x, m_lookat.y, m_lookat.z,
            m_up.x, m_up.y, m_up.z );
}


void CSimpCamera::YawAndPitch(float yaw, float pitch)
{
  m_rotX += yaw;
  
  if (m_rotX > 2*PI)
    m_rotX -= PI*2;
  
  if (m_rotX < 0)
    m_rotX += PI*2;

  m_rotY -= pitch;

  if (m_rotY > PITCH_MAX)
    m_rotY = PITCH_MAX;
  if (m_rotY < -PITCH_MAX)
    m_rotY = -PITCH_MAX;

  // use the camera's view angle to correctly set up the view matrix
  m_lookat.x = m_pos.x + cosf(m_rotY) * sinf(m_rotX);
  m_lookat.y = m_pos.y + sinf(m_rotY);
  m_lookat.z = m_pos.z - cosf(m_rotY) * cosf(m_rotX);

  m_lookat.Normalize();
}
