/*************************************************************************
MGLApp.cpp

Main application class.

Author   :   Dave Astle

Written for More OpenGL Game Programming
*************************************************************************/

#ifdef WIN32
	#define WIN32_LEAN_AND_MEAN
	#define WIN32_EXTRA_LEAN
	#include <windows.h>
#endif

#include "MGLApp.h"

GLfloat vertices[] = {
  -1.0, -2.0, 0.0,
  2.0, 0.0, 0.0,
  0.0, 2.0, 0.0
};


GLubyte colors[] = {
  255, 0, 0,
  0, 255, 0,
  0, 0, 255
};


MGLApp::MGLApp()
{
}

MGLApp::~MGLApp()
{
}

bool MGLApp::Init()
{	
	if (!GLeeInit())
		return false;

  glEnableClientState(GL_VERTEX_ARRAY);
  glEnableClientState(GL_COLOR_ARRAY);

  if (GLEE_ARB_vertex_buffer_object)
  {
    glGenBuffers(1, &m_triangleBuffer);
    glBindBuffer(GL_ARRAY_BUFFER, m_triangleBuffer);

    // Create a buffer big enough to hold 9 vertices with position and color. Leave it empty for now.
    glBufferData(GL_ARRAY_BUFFER, 9 * (sizeof(GLfloat) + sizeof(GLubyte)), NULL, GL_STATIC_DRAW);
    // Load the positions.
    glBufferSubData(GL_ARRAY_BUFFER, 0, 9 * sizeof(GLfloat), vertices);
    // Load the colors.
    glBufferSubData(GL_ARRAY_BUFFER, 9 * sizeof(GLfloat), 9 * sizeof(GLubyte), colors);

    glVertexPointer(3, GL_FLOAT, 0, (void*)0);
    glColorPointer(3, GL_UNSIGNED_BYTE, 0, (void*)(9 * sizeof(GLfloat)));
  } 
  else
  {
    glVertexPointer(3, GL_FLOAT, 0, vertices);
    glColorPointer(3, GL_UNSIGNED_BYTE, 0, colors);
  }

	return true;
}

bool MGLApp::Shutdown()
{
  glDeleteBuffers(1, &m_triangleBuffer);
	return true;
}

void MGLApp::SetupProjection(int width, int height)
{
	// avoid div by zero
	if( height == 0 )
		height = 1;					

	// set up GL viewport
	glViewport( 0, 0, width, height );

	// set up a perspective projection
	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	gluPerspective( 45.0f, (GLfloat)width/(GLfloat)height, 1.0f, 1000.0f );
}

void MGLApp::Update( double dt )
{
}

void MGLApp::Render()
{
	glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );

	// set up the camera
	glMatrixMode( GL_MODELVIEW );
	glLoadIdentity();
  gluLookAt(0.0, 0.0, 10.0, 0.0, 0.0, 0.0, 0.0, 0.1, 0.0);

  glDrawArrays(GL_TRIANGLES, 0, 3);
}
